upoints

# `upoints`

# User-visible changes

Contents

- User-visible changes
- 0.11.0 - 2008-05-20
- 0.10.0 - 2008-03-27
- 0.9.0 - 2008-01-25
- 0.8.0 - 2008-01-09
- 0.7.0 - 2008-01-08
- 0.6.0 - 2007-12-14
- 0.5.0 - 2007-01-01
- 0.4.0 - 2007-10-02
- 0.3.0 - 2007-10-01

# 0.11.0 - 2008-05-20

> - This is likely to be the final non-bugfix release before v1.0.0 is cut, if you don't like how something works now is the time to speak up!
> - This package has been renamed `upoints` from `earth_distance` to better reflect its usage, and as a bonus it is more compliant with PEP-8's naming guidelines
> - Added support for a generic `Point` object container type
> - Support for reading OpenCellID exports
> - Can now use lxml for XML processing on systems where `cElementTree` isn't available
> - Python "egg" packages can now be built if setuptools is installed

# 0.10.0 - 2008-03-27

> - Support for reading and writing GPX v1.0 files
> - Support for GPX `trkpt` elements

# 0.9.0 - 2008-01-25

> - Support for reading OpenStreetMap exports
> - Support for reading configuration file in `edist.py` for enable simple named location support.

# 0.8.0 - 2008-01-09

> - Support for reading GPS eXchange format

# 0.7.0 - 2008-01-08

> - Support for reading NMEA 0183 formatted data

# 0.6.0 - 2007-12-14

> - Support for importing KML data files
> - Support for importing zoneinfo zone descriptions
> - Latitude and longitude values are now managed attributes, and can be updated in place(as can Baken Maidenhead locators)
> - Locations now support a much prettier Unicode output mode
> - `edist.py` a new user script that allows one to manipulate locations in various ways from the command line
> - Package no longer requires `make` for development functions
> - Tests no longer span network boundaries, and should run on any default Python install once initially seeded

# 0.5.0 - 2007-01-01

> - All `Point` children now have dictionary-based collection objects, named `<base>s`
> - Import and export routines of `Point` objects have now moved in to their respective collection objects

# 0.4.0 - 2007-10-02

> - Support for baken data files in `baken`

# 0.3.0 - 2007-10-01

> - Support for geonames database exports in `geonames`
> - Support for ISO 6709 coordinate strings in `utils.from_iso6709` and `utils.to_iso6709`
> - Support for Maidenhead locator strings in `utils.from_grid_locator` and `utils.to_grid_locator`
> - Support for creating Xearth markers files with any `Point`-compatible objects using `utils.dump_xearth_markers`